@@ -1,12 +1,11 @@
 from .auth import AuthState
-from priceloop_api import Client
+from priceloop_api import AuthenticatedClient
 from typing import Dict
 import attr
 
 default_host = "alpha.priceloop.ai"
 
-
-class PriceloopClient(Client):
+class PriceloopClient(AuthenticatedClient):
     """A Client which has been authenticated for use on secured endpoints"""
 
     auth_state: AuthState
@@ -17,8 +16,9 @@ class PriceloopClient(Client):
         self.cookies = {}
         self.headers = {}
         self.verify_ssl = True
-        self.raise_on_unexpected_status = False
+        self.raise_on_unexpected_status = True
         self.auth_state = auth_state
+        self.follow_redirects = False
 
     def get_headers(self) -> Dict[str, str]:
         """Get headers to be used in authenticated endpoints"""
@@ -26,6 +26,6 @@ class PriceloopClient(Client):
         return {"Authorization": auth_header_value, **self.headers}
 
     @staticmethod
-    def with_credentials(username: str, password: str, host: str = default_host):
+    def with_credentials(username: str, password: str, host: str = default_host) -> "PriceloopClient":
         auth_state = AuthState(username, password, host)
         return PriceloopClient(auth_state)
